pub struct ExemplarCharactersData<'data>(pub CodePointInversionListAndStringList<'data>);Expand description
A set of characters and strings which share a particular property value.
๐ง This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Tuple Fields
0: CodePointInversionListAndStringList<'data>Trait Implementations
Sourceimpl<'data> Clone for ExemplarCharactersData<'data>
impl<'data> Clone for ExemplarCharactersData<'data>
Sourcefn clone(&self) -> ExemplarCharactersData<'data>
fn clone(&self) -> ExemplarCharactersData<'data>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'data> Debug for ExemplarCharactersData<'data>
impl<'data> Debug for ExemplarCharactersData<'data>
Sourceimpl MaybeAsVarULE for ExemplarCharactersData<'_>
impl MaybeAsVarULE for ExemplarCharactersData<'_>
Sourceimpl<'data> PartialEq for ExemplarCharactersData<'data>
impl<'data> PartialEq for ExemplarCharactersData<'data>
Sourcefn eq(&self, other: &ExemplarCharactersData<'data>) -> bool
fn eq(&self, other: &ExemplarCharactersData<'data>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<'yoke> Yokeable<'yoke> for ExemplarCharactersData<'static>
impl<'yoke> Yokeable<'yoke> for ExemplarCharactersData<'static>
Sourcetype Output = ExemplarCharactersData<'yoke>
type Output = ExemplarCharactersData<'yoke>
This type MUST be
Self with the 'static replaced with 'a, i.e. Self<'a>Sourcefn transform_owned(self) -> Self::Output
fn transform_owned(self) -> Self::Output
Sourceimpl<'zf, 'zf_inner> ZeroFrom<'zf, ExemplarCharactersData<'zf_inner>> for ExemplarCharactersData<'zf>
impl<'zf, 'zf_inner> ZeroFrom<'zf, ExemplarCharactersData<'zf_inner>> for ExemplarCharactersData<'zf>
Sourcefn zero_from(this: &'zf ExemplarCharactersData<'zf_inner>) -> Self
fn zero_from(this: &'zf ExemplarCharactersData<'zf_inner>) -> Self
Clone the other
C into a struct that may retain references into C.impl<'data> Eq for ExemplarCharactersData<'data>
impl<'data> StructuralPartialEq for ExemplarCharactersData<'data>