pub struct Parents<'data> {
pub parents: ZeroMap<'data, PotentialUtf8, (Language, Option<Script>, Option<Region>)>,
}Expand description
Locale fallback rules derived from CLDR parent locales data.
Fields
parents: ZeroMap<'data, PotentialUtf8, (Language, Option<Script>, Option<Region>)>Map from language identifier to language identifier, indicating that the language on the left should inherit from the language on the right.